@@ -79,7 +79,10 @@ def fill_json_data():
 
 def update_modified_status():
     os.chdir(GIT_DIR)
-    json_obj, json_file = open_json(GIT_JSON_NAME)
+    if GIT_JSON_NAME in os.listdir(os.curdir):
+        json_obj, json_file = open_json(GIT_JSON_NAME)
+    else:
+        print("Error, no JSON FILE FOUND")
     dir_list = os.listdir(REPO_DIR)
     os.chdir(REPO_DIR)
     file_place = ''
@@ -102,7 +105,11 @@ def update_modified_status():
 
 def display_file_statuses():
     os.chdir(GIT_DIR)
-    json_obj = read_only_json(GIT_JSON_NAME)
+    if GIT_JSON_NAME in os.listdir(os.curdir):
+        json_obj, json_file = open_json(GIT_JSON_NAME)
+    else:
+        print("Error, no JSON FILE FOUND")
+        return
     if States.COMMITED in json_obj:
         del json_obj[States.COMMITED]
     for state, files in json_obj.items():
@@ -112,7 +119,11 @@ def display_file_statuses():
 
 def commit_files():
     os.chdir(GIT_DIR)
-    json_obj, json_file = open_json(GIT_JSON_NAME)
+    if GIT_JSON_NAME in os.listdir(os.curdir):
+        json_obj, json_file = open_json(GIT_JSON_NAME)
+    else:
+        print("Error, no JSON FILE FOUND")
+        return
     state = States.STAGED
     files = json_obj.get(state)
     files = {k: v for k, v in files.items()}
@@ -124,7 +135,11 @@ def commit_files():
 
 def add_files(arg):
     os.chdir(GIT_DIR)
-    json_obj, json_file = open_json(GIT_JSON_NAME)
+    if GIT_JSON_NAME in os.listdir(os.curdir):
+        json_obj, json_file = open_json(GIT_JSON_NAME)
+    else:
+        print("Error, no JSON FILE FOUND")
+        return
     if arg == "*":
         states = [States.NEW, States.MODIFIED]
         for state in states:
